@@ -26,28 +26,20 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "© 1999-2020 ImageMagick Studio LLC"
+#define MagickCopyright  "© 1999-2021 ImageMagick Studio LLC"
 #define MagickLibVersion  0x70A
 #define MagickLibVersionText  "7.0.10"
 #define MagickLibVersionNumber  8,0,0
-#define MagickLibAddendum  "-56"
+#define MagickLibAddendum  "-57"
 #define MagickLibInterface  8
 #define MagickLibMinInterface  8
-#if defined(_WINDOWS)
-#  if defined(_WIN64)
-#    define MagickPlatform "x64"
-#  else
-#    define MagickPlatform "x86"
-#  endif
-#else
 #define MagickPlatform  "aarch64"
-#endif
 #define MagickppLibVersionText  "7.0.10"
 #define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-56"
+#define MagickppLibAddendum  "-57"
 #define MagickppLibInterface  4
 #define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2021-01-06"
+#define MagickReleaseDate  "2021-01-10"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
